#
# spec file for package xf86-video-chips
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-chips
Version:        1.5.0
Release:        2.1
Summary:        Chips and Technologies video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
#Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.bz2
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.0.99.901
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v0000102Cd*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    aarch64 %{arm} s390 s390x
%x11_abi_videodrv_req

%description
chips is an Xorg driver for Chips and Technologies video cards.

The majority of the Chips and Technologies chipsets are supported by
this driver. In general the limitation on the capabilities of this
driver are determined by the chipset on which it is run. Where possible,
this driver provides full acceleration and supports the following
depths: 1, 4, 8, 15, 16, 24 and on the latest chipsets an 8+16 overlay
mode. All visual types are supported for depth 1, 4 and 8 and both
TrueColor and DirectColor visuals are supported where possible.
Multi-head configurations are supported on PCI or AGP buses.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/chips_drv.so
%{_mandir}/man4/chips.4%{?ext_man}

%changelog
* Wed Aug 28 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable build on aarch64 and %%arm as it fails to build and
  unlikely used on those archs
* Mon Mar 25 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.5.0
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * gitlab CI: ensure libtool is installed in build container
  * configure: Use LT_INIT from libtool 2 instead of deprecated AC_PROG_LIBTOOL
  * configure: quote call to AC_LANG_SOURCE in AC_LINK_IFELSE
  * Add X.Org's standard C warning flags to AM_CFLAGS
  * Fix -Wmisleading-indentation warning in chipsPreInitHiQV()
  * Handle 4 -Wmissing-prototypes warnings
  * AsmMacros.h: convert function definitions from K&R to C89
  * unifdef NCR
  * unifdef Lynx
  * unifdef __SCO__
  * unifdef __USLC__
  * Remove ifdef checks for non-Solaris SVR4 systems
  * Quiet -Wredundant-decls from xorg/os.h fallbacks for new libc functions
* Sun Feb 17 2019 sndirsch@suse.com
- update to release 1.4.0
  * This is a bug fix release of Chips & Technologies DDX for X.Org
    X Server. There was an X Server crash bug with the Version 1.3
    and older code when the code was converted for a newer vgaHW
    ABI. This affects devices older than the HiQVideo generation.
    This release fixes this particular issue. Please note that the
    code may not compile against X Server 1.20 since it no longer
    supports 24-bit color.
* Sat Jan  5 2019 sndirsch@suse.com
- update to release 1.3.0
  * This is a maintenance release of Chips & Technologies DDX for
    X.Org X Server.  No testing has been done due to the lack of
    equipment availability.
* Thu Jan 19 2017 sndirsch@suse.com
- update to release 1.2.7
  * Adapt Block/WakeupHandler signature for ABI 23
- supersedes U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
* Tue Nov 29 2016 sndirsch@suse.com
- U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
  * Adapt Block/WakeupHandler signature for ABI 23
* Thu Oct  1 2015 sndirsch@suse.com
- update to release 1.2.6
  * Remove mibstore.h
  * ddc: Use own thunk function instead of vgaHWddc1SetSpeedWeak
  * Update for xserver 1.17
  * Add iopl.h to source lists in util/Makefile.am so it gets packaged
  * Require ANSI C89 pre-processor, drop pre-C89 token pasting support
- supersedes patches U_Update-for-xserver-1.17.patch, U_mibstore.patch
* Fri Feb  6 2015 sndirsch@suse.com
- U_Update-for-xserver-1.17.patch
  * fixes build against xorg-server 1.17
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Tue Mar 19 2013 hrvoje.senjan@gmail.com
- Add mibstore.patch, fixes build with xorg-server 1.14
* Wed Sep 12 2012 sndirsch@suse.com
- update to release 1.2.5_bde6593
  * Fall back to shadowfb if XAA is unavailable
  * Fix for new vgaHW ABI
  * gut the overlay 8/16 support from driver.
  * add compat API header
  * use new scrn/screen conversion APIs.
  * move to new compat API.
  * drop usage of deprecated xf86PciInfo.h
  * build without XAA support at all.
  * fix make dist.
  * Use malloc/calloc/realloc/free directly
  * configure.ac: Remove AM_PROG_CC_C_O
  * util: Consolidate common macros
  * Fix implicit declaration of iopl
  * Build fix for ABI Version 12
  * PciTag is unused when using libpciaccess
  * Add iopl.h to source lists in util/Makefile.am so it gets
    packaged
* Fri Apr 20 2012 vuntz@opensuse.org
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
- Add xf86-video-chips-git-fixes.patch: several fixes from git for
  compatibility xith Xorg ABI 1.12 and build warnings.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-chips from xorg-x11-driver-video.
  Initial version: 1.2.4.
